Crate tokio_tls_helper

Crate tokio_tls_helper 

Structs

Certificate
Represents a X509 certificate.
ClientTlsConfig
Configures TLS settings for endpoints.
Identity
Represents a private key and X509 certificate.
ServerTlsConfig
TlsAcceptor
TlsClientStream
A wrapper around an underlying raw stream which implements the TLS or SSL protocol.
TlsConnector
TlsServerStream
A wrapper around an underlying raw stream which implements the TLS or SSL protocol.

Enums

Error
General error definition for the project