Structs
- Certificate
- Represents a X509 certificate.
- Client
TlsConfig - Configures TLS settings for endpoints.
- Identity
- Represents a private key and X509 certificate.
- Server
TlsConfig - TlsAcceptor
- TlsClient
Stream - A wrapper around an underlying raw stream which implements the TLS or SSL protocol.
- TlsConnector
- TlsServer
Stream - A wrapper around an underlying raw stream which implements the TLS or SSL protocol.
Enums
- Error
- General error definition for the project